import matplotlib.pyplot as plt
import pandas as pd
import matplotlib.dates as mdates
from pandas.plotting import register_matplotlib_converters
register_matplotlib_converters()
import matplotlib.ticker as tick

#Extraction des données depuis le fichier .csv :
soleil=pd.read_csv('SoleilLune2022.csv',
sep=';', 
usecols=[1, 2, 4, 6], 
names=['date', 'lever', 'midi', 'coucher'], 
parse_dates=['date'], 
skiprows=1, 
nrows=365, 
)
#Extraction des listes de données pour les graphes :
soleil=soleil.set_index('date')
dates=soleil.index
lever=soleil['lever']
coucher=soleil['coucher']
midi=soleil['midi']
EDT=midi-12#calcul de l'équation du temps

plt.rcParams["font.family"] = "Ubuntu"
plt.rcParams["font.size"] = 9

def HHmm(heure, lever):#écrit en base 60
    H=int(heure)
    min=round((heure-H)*60)
    if min<10:
        min="0"+str(min)
    return str(H)+'h'+str(min)[:-2]

def pointMinimum(liste, datemin, datemax):
    periode=liste.loc[datemin:datemax]
    Tmin=periode.idxmin(periode)
    Hmin=periode.values.min()
    ax=plt.gca()
    ax.scatter(Tmin, Hmin, c='white', facecolor='w',
    edgecolor='k', zorder=2)

def pointMaximum(liste, datemin, datemax):
    periode=liste.loc[datemin:datemax]
    Tmax=periode.idxmax(periode)
    Hmax=periode.values.max()
    ax=plt.gca()
    ax.scatter(Tmax, Hmax, c='white', facecolor='w',
    edgecolor='k', zorder=2)

#Paramètres du graphique :
fig=plt.figure(figsize=(7, 9), 
tight_layout=True
)
#plt.suptitle("Heures extrêmes de lever et de coucher du Soleil - équation du temps", fontsize=16, y=0.99)

def mmss(min, EDT):#écrit en base 60
    M=round(min*60)
#    sec=round((M-int(M))*60, 2)
    return str(M)[:-2]+' min'#+str(sec)[:-2]

#Graphe 4---------------------------------------------------
ax4=plt.subplot(211)
ax4.set_title("Coucher du Soleil au solstice d'été")
ax4.plot(dates, coucher, label='temps moyen', c='C0')
ax4.plot(dates, coucher-EDT, label='temps vrai', c='C2', ls='--')
ax4.grid()
ax4.yaxis.set_major_formatter(tick.FuncFormatter(HHmm))
locator2 = mdates.AutoDateLocator(minticks=15, maxticks=15, interval_multiples=True)
formatter = mdates.ConciseDateFormatter(locator2)
ax4.xaxis.set_major_locator(locator2)
ax4.xaxis.set_major_formatter(formatter)
ax4.set_xlim('2022-06-11', '2022-06-29')
ax4.set_ylim(20, 20.17)
ax4.legend()

pointMaximum(coucher, '2022-06-10', '2022-06-30')
pointMaximum(coucher-EDT, '2022-06-10', '2022-06-30')

#Graphe 5---------------------------------------------------
ax5=plt.subplot(212)
ax5.set_title("Lever du Soleil au solstice d'été")
ax5.plot(dates, lever, label='temps moyen', c='C1')
ax5.plot(dates, lever-EDT, label='temps vrai', c='C3', ls='--')
ax5.grid()
ax5.yaxis.set_major_formatter(tick.FuncFormatter(HHmm))
#locator2 = mdates.AutoDateLocator(minticks=15, maxticks=15, interval_multiples=True)
ax5.xaxis.set_major_locator(locator2)
ax5.xaxis.set_major_formatter(formatter)
ax5.set_xlim('2022-06-11', '2022-06-29')
ax5.set_ylim(3.85, 4.01)
ax5.legend()
pointMinimum(lever, '2022-06-10', '2022-06-30')
pointMinimum(lever-EDT, '2022-06-10', '2022-06-30')

##Encadré 1
#ax8=plt.subplot(338)
#ax8.axis('off')
#plt.rcParams.update({"font.family": "sans-serif"})
#plt.text(0, 1,
#r"\normalsize"
#r"\begin{minipage}{9.50cm}"
#r"\textbf{Solstice d'été : }"
#r"c'est généralement le 21 juin que le jour dure le plus longtemps. "
#r"Cependant, du fait de l'équation du temps (env. +2 min), c'est le 25 juin "
#r"que le Soleil se couche le plus tard.\\\\"
#r"De même, l'heure minimale de lever du Soleil à cette période "
#r"se produit vers le 16 juin."
#r"\end{minipage}"
#, transform=ax8.transAxes, usetex=True, va='top')

#plt.text(0, 1,
#r"\normalsize"
#r"\begin{minipage}{9.50cm}"
#r"\textbf{Solstice d'hiver : }"
#r"l'équation du temps est négative et s'annule le 25 décembre. "
#r"L'heure de coucher du Soleil est minimale le 12 décembre. "
#r"Au-delà de cette date, le Soleil se couche plus tard, "
#r"bien que les journées continuent à raccourcir (jusqu'au 21 décembre, en général).\\\\"
#r"L'heure de lever de Soleil continue à augmenter jusqu'au 31 décembre.\\\\\\"
#r"Les calculs d’éphémérides de position des corps du Système solaire"
#r" ont été réalisés par le service de calcul des éphémérides de l’IMCCE"
#r" à travers son portail Système solaire (https://ssp.imcce.fr)"
#r"\end{minipage}"
#, transform=ax9.transAxes, usetex=True, va='top')

fig.savefig("LeverCoucherSoleil_2.png", dpi=200)
plt.show()
